From 81ad450883499841f254cba7c2213412bc762380 Mon Sep 17 00:00:00 2001
From: Zorro Liu <lyx@rock-chips.com>
Date: Fri, 6 Aug 2021 15:29:45 +0800
Subject: [PATCH] drivers: video: rk_eink: support multi pmics define

dts define as:
&ebc_dev {
    pmic = <&tps65185 &sy7673a &xxxx>;
    .
    .
    .
};

Signed-off-by: Zorro Liu <lyx@rock-chips.com>
Change-Id: I9c3c9188e5c91f3bf61478a6b83a2ab78dd585ba
---
 drivers/video/rk_eink/rk_eink_display.c | 24 ++++++++++++++++++++----
 1 file changed, 20 insertions(+), 4 deletions(-)

diff --git a/drivers/video/rk_eink/rk_eink_display.c b/drivers/video/rk_eink/rk_eink_display.c
index a8db27a5cb..ff0e590d39 100644
--- a/drivers/video/rk_eink/rk_eink_display.c
+++ b/drivers/video/rk_eink/rk_eink_display.c
@@ -690,7 +690,9 @@ int rockchip_eink_show_charge_logo(int logo_type)
 
 static int rockchip_eink_display_probe(struct udevice *dev)
 {
-	int ret, vcom;
+	int ret, vcom, size, i;
+	const fdt32_t *list;
+	uint32_t phandle;
 	struct rockchip_eink_display_priv *priv = dev_get_priv(dev);
 
 	/* Before relocation we don't need to do anything */
@@ -705,9 +707,23 @@ static int rockchip_eink_display_probe(struct udevice *dev)
 		return ret;
 	}
 
-	ret = uclass_get_device_by_phandle(UCLASS_I2C_GENERIC, dev,
-					   "pmic",
-					   &priv->ebc_pwr_dev);
+	list = dev_read_prop(dev, "pmic", &size);
+	if (!list) {
+		dev_err(dev, "Cannot get pmic prop\n");
+		return -EINVAL;
+	}
+
+	size /= sizeof(*list);
+	for (i = 0; i < size; i++) {
+		phandle = fdt32_to_cpu(*list++);
+		ret = uclass_get_device_by_phandle_id(UCLASS_I2C_GENERIC,
+						      phandle,
+						      &priv->ebc_pwr_dev);
+		if (!ret) {
+			printf("Eink: use pmic %s\n", priv->ebc_pwr_dev->name);
+			break;
+		}
+	}
 	if (ret) {
 		dev_err(dev, "Cannot get pmic: %d\n", ret);
 		return ret;
-- 
2.17.1

